# -*- coding: utf-8 -*-

import os
import json
from typing import List

import pandas as pd

from ydl_ai_recommender.src.utils import get_data_path
from ydl_ai_recommender.src.utils.log import create_logger
from .manager import Manager

# class Manager():
#     def __init__(self, logger=None) -> None:
#         if logger is None:
#             self.logger = create_logger(__name__)
#         else:
#             self.logger = logger

#         self.local_file_dir = get_data_path()


class DatabaseDataManager(Manager):
    def __init__(self, client=None, logger=None) -> None:
        super().__init__(logger)
        self.client = client

    def fetch_data_from_db(self, sql: str) -> List:
        if self.client is None:
            self.logger.error('未连接数据库')
            raise

        return self.client.query(sql)

    def load_xlsx_data(self, filename):
        return pd.read_excel(os.path.join(self.local_file_dir, filename), dtype=str)
    
    def save_xlsx_data(self, df, filename):
        df.to_excel(os.path.join(self.local_file_dir, filename), index=None)

    def load_csv_data(self, filename):
        return pd.read_csv(os.path.join(self.local_file_dir, filename), dtype=str)
    
    def save_csv_data(self, df, filename):
        df.to_csv(os.path.join(self.local_file_dir, filename), encoding='utf-8', index=False)

    def load_json_data(self, filename):
        with open(os.path.join(self.local_file_dir, filename), 'r', encoding='utf-8') as f:
            return json.load(f)
    
    def save_json_data(self, data, filename):
        with open(os.path.join(self.local_file_dir, filename), 'r', encoding='utf-8') as f:
            return json.dump(data, f, ensure_ascii=False)

    def update_data(self):
        raise NotImplementedError

    def update_test_data(self, conditions):
        raise NotImplementedError
